# Graphite/silicon negative electrode parameters

Parameters for a composite graphite/silicon negative electrode, from the paper

> Ai, W., Kirkaldy, N., Jiang, Y., Offer, G., Wang, H., & Wu, B. (2022). A composite electrode model for lithium-ion batteries with silicon/graphite negative electrodes. Journal of Power Sources, 527, 231142.

based on the paper

> Chang-Hui Chen, Ferran Brosa Planella, Kieran O’Regan, Dominika Gastol, W. Dhammika Widanage, and Emma Kendrick. ["Development of Experimental Techniques for Parameterization of Multi-scale Lithium-ion Battery Models."](https://iopscience.iop.org/article/10.1149/1945-7111/ab9050) Journal of the Electrochemical Society 167 (2020): 080534

and references therein.
